aboutsummaryrefslogtreecommitdiff
path: root/tests/neg/assignments.scala
diff options
context:
space:
mode:
Diffstat (limited to 'tests/neg/assignments.scala')
-rw-r--r--tests/neg/assignments.scala4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/neg/assignments.scala b/tests/neg/assignments.scala
index 2314783fe..5be107717 100644
--- a/tests/neg/assignments.scala
+++ b/tests/neg/assignments.scala
@@ -13,11 +13,11 @@ object assignments {
x = x + 1
x *= 2
- x_= = 2 // should give missing arguments + reassignment to val
+ x_= = 2 // error should give missing arguments + // error reassignment to val
}
var c = new C
- import c._ // should give: prefix is not stable
+ import c._ // error should give: prefix is not stable
x = x + 1
x *= 2
}